@@ -40,6 +40,11 @@ class Instrument:
 			if 'end' not in parameters:
 				self.end = self.start + self.step
 
+	def reset(self):
+		self.track = Track()
+		if hasattr(self, "bar"):
+			del self.bar
+
 	def import_fluidsynth(self):
 		global fluidsynth
 		from mingus.midi import fluidsynth
