@@ -76,12 +76,30 @@ class ImproviserMainWindow(QtGui.QMainWindow):
 		self.connect(self.ui.removeblock,
 			QtCore.SIGNAL("clicked()"),
 			self.remove_block)
+		self.connect(self.ui.clearblocks,
+			QtCore.SIGNAL("clicked()"),
+			self.ui.blocks.clear)
+		self.connect(self.ui.upblock,
+			QtCore.SIGNAL("clicked()"),
+			lambda: self.swap_list_item(self.ui.blocks))
+		self.connect(self.ui.downblock,
+			QtCore.SIGNAL("clicked()"),
+			lambda: self.swap_list_item(self.ui.blocks, False))
 		self.connect(self.ui.removeinstrument,
 			QtCore.SIGNAL("clicked()"),
 			self.remove_instrument)
 		self.connect(self.ui.removeprogression,
 			QtCore.SIGNAL("clicked()"),
 			self.remove_progression)
+		self.connect(self.ui.upprogression,
+			QtCore.SIGNAL("clicked()"),
+			lambda: self.swap_list_item(self.ui.progressions))
+		self.connect(self.ui.downprogression,
+			QtCore.SIGNAL("clicked()"),
+			lambda: self.swap_list_item(self.ui.progressions, False))
+		self.connect(self.ui.clearprogressions,
+			QtCore.SIGNAL("clicked()"),
+			self.ui.progressions.clear)
 		self.connect(self.ui.action_About,
 			QtCore.SIGNAL("activated()"),
 			self.show_about)
@@ -95,7 +113,7 @@ class ImproviserMainWindow(QtGui.QMainWindow):
 			QtCore.SIGNAL("activated()"),
 			self.save_dialog)
 		
-			
+	
 
 	def set_defaults(self):
 		self.ui.resolution.setCurrentIndex(3) # '8'
@@ -288,6 +306,33 @@ class ImproviserMainWindow(QtGui.QMainWindow):
 			if combo.itemText(x) == text:
 				return x
 		return -1
+
+	def swap_list_item(self, lst, up = True):
+		index = lst.currentRow()
+		if index < 0:
+			return
+		c = lst.count()
+		cur = lst.item(index)
+		i1 = cur.text()
+		if up:
+			if index > 0:
+				i2 = lst.item(index - 1)
+				lst.setCurrentRow(index - 1)
+			else:
+				return 
+
+		else:
+			if index < c - 1:
+				i2 = lst.item(index + 1)
+				lst.setCurrentRow(index + 1)
+			else:
+				return
+		t = i2.text()
+		i2.setText(i1)
+		cur.setText(t)
+
+				
+
 	
 	def set_status(self, msg):
 		s = self.statusBar()
